@@ -4,7 +4,6 @@ Created on Tue May  4 15:59:03 2021
 
 @author: braxt
 """
-from _typeshed import NoneType
 from math import log
 import time
 import sys
@@ -69,7 +68,7 @@ class ProgressBar(object):
 [{(self.char*int(self.pos*self.maxlen)).ljust(self.maxlen)}] {st}\t\r')
 
     def update(self, completed=None):
-        if isinstance(completed, NoneType):
+        if completed == None:
             completed = self.completed + 1
         if self.items:
             t = time.time() - self.last_time
